//     wink-sentiment
//     Accurate and fast sentiment scoring of phrases with hashtags, emoticons & emojis.
//
//     Copyright (C) 2017-18  GRAYPE Systems Private Limited
//
//     This file is part of “wink-sentiment”.
//
//     “wink-sentiment” is free software: you can redistribute
//     it and/or modify it under the terms of the GNU Affero
//     General Public License as published by the Free
//     Software Foundation, version 3 of the License.
//
//     “wink-sentiment” is distributed in the hope that it will
//     be useful, but WITHOUT ANY WARRANTY; without even
//     the implied warranty of MERCHANTABILITY or FITNESS
//     FOR A PARTICULAR PURPOSE.  See the GNU Affero General
//     Public License for more details.
//
//     You should have received a copy of the GNU Affero
//     General Public License along with “wink-sentiment”.
//     If not, see <http://www.gnu.org/licenses/>.

//
// This is dervied data from Emoji Sentiment Ranking 1.0. The original research
// reference: Kralj Novak, Petra; Smailović, Jasmina; Sluban, Borut and Mozetič,
// Igor, 2015, Emoji Sentiment Ranking 1.0, Slovenian language resource repository
// CLARIN.SI, http://hdl.handle.net/11356/1048. The derived data only includes top
// emojis. The sentiment score has been computed by subtracting the ratio of negative
// to total occurrences from the positive to the total occurrences and then rescaling
// it to a range of -5 to +5.

// The original data was published under Creative Commons -
// Attribution-ShareAlike 4.0 International (CC BY-SA 4.0) license. You may
// read the license at https://creativecommons.org/licenses/by-sa/4.0/ URL.
// Sourced from https://www.clarin.si/repository/xmlui/handle/11356/1048 URL.
var emojis = {
  '😂': 1,
  '❤': 4,
  '♥': 3,
  '😍': 3,
  '😭': 0,
  '😘': 4,
  '😊': 3,
  '👌': 3,
  '💕': 3,
  '👏': 3,
  '😁': 2,
  '☺': 3,
  '♡': 3,
  '👍': 3,
  '😩': -2,
  '🙏': 2,
  '✌': 2,
  '😏': 2,
  '😉': 2,
  '🙌': 3,
  '🙈': 2,
  '💪': 3,
  '😄': 2,
  '😒': -2,
  '💃': 4,
  '💖': 4,
  '😃': 3,
  '😔': -1,
  '😱': 1,
  '🎉': 4,
  '😜': 2,
  '☯': 0,
  '🌸': 3,
  '💜': 3,
  '💙': 4,
  '✨': 2,
  '😳': 0,
  '💗': 3,
  '★': 1,
  '█': 0,
  '☀': 2,
  '😡': -1,
  '😎': 2,
  '😢': 0,
  '💋': 3,
  '😋': 3,
  '🙊': 2,
  '😴': 0,
  '🎶': 3,
  '💞': 4,
  '😌': 2,
  '🔥': 1,
  '💯': 1,
  '🔫': -1,
  '💛': 4,
  '💁': 2,
  '💚': 3,
  '♫': 1,
  '😞': -1,
  '😆': 2,
  '😝': 2,
  '😪': 0,
  '😫': -1,
  '😅': 1,
  '👊': 1,
  '💀': -1,
  '😀': 3,
  '😚': 4,
  '😻': 3,
  '©': 1,
  '👀': 0,
  '💘': 3,
  '🐓': 0,
  '☕': 1,
  '👋': 2,
  '✋': 1,
  '🎊': 4,
  '🍕': 2,
  '❄': 3,
  '😥': 1,
  '😕': -2,
  '💥': 1,
  '💔': -1,
  '😤': -1,
  '😈': 1,
  '►': 1,
  '✈': 2,
  '🔝': 2,
  '😰': 0,
  '⚽': 3,
  '😑': -2,
  '👑': 4,
  '😹': 1,
  '👉': 2,
  '🍃': 2,
  '🎁': 4,
  '😠': -2,
  '🐧': 2,
  '☆': 2,
  '🍀': 1,
  '🎈': 4,
  '🎅': 2,
  '😓': 0,
  '😣': -1,
  '😐': -2,
  '✊': 2,
  '😨': -1,
  '😖': -1,
  '💤': 2,
  '💓': 3,
  '👎': -1,
  '💦': 2,
  '✔': 1,
  '😷': -1,
  '⚡': 1,
  '🙋': 2,
  '🎄': 3,
  '💩': -1,
  '🎵': 3,
  '➡': 1,
  '😛': 3,
  '😬': 1,
  '👯': 2,
  '💎': 3,
  '🌿': 2,
  '🎂': 3,
  '🌟': 2,
  '🔮': 1,
  '❗': 1,
  '👫': 1,
  '🏆': 4,
  '✖': 2,
  '☝': 2,
  '😙': 4,
  '⛄': 3,
  '👅': 2,
  '♪': 3,
  '🍂': 3,
  '💏': 2,
  '🔪': 0,
  '🌴': 3,
  '👈': 2,
  '🌹': 3,
  '🙆': 3,
  '➜': 1,
  '👻': 1,
  '💰': 1,
  '🍻': 3,
  '🙅': -1,
  '🌞': 3,
  '🍁': 2,
  '⭐': 3,
  '▪': 1,
  '🎀': 3,
  '━': 1,
  '☷': 0,
  '🐷': 2,
  '🙉': 2,
  '🌺': 3,
  '💅': 2,
  '🐶': 3,
  '🌚': 2,
  '👽': 2,
  '🎤': 2,
  '👭': 2,
  '🎧': 2,
  '👆': 2,
  '🍸': 3,
  '🍷': 2,
  '®': 1,
  '🍉': 3,
  '😇': 3,
  '☑': 1,
  '🏃': 2,
  '😿': -2,
  '│': 2,
  '💣': 0,
  '🍺': 3,
  '▶': 1,
  '😲': 0,
  '🎸': 3,
  '🍹': 3,
  '💫': 3,
  '📚': 2,
  '😶': -1,
  '🌷': 3,
  '💝': 3,
  '💨': 2,
  '🏈': 3,
  '💍': 2,
  '☔': 1,
  '👸': 3,
  '🇪': 3,
  '░': 0,
  '🍩': 2,
  '👾': 2,
  '☁': 2,
  '🌻': 3,
  '😵': 0,
  '📒': 0,
  '↿': 3,
  '🐯': 2,
  '👼': 2,
  '🍔': 1,
  '😸': 2,
  '👶': 2,
  '↾': 3,
  '💐': 4,
  '🌊': 3,
  '🍦': 2,
  '🍓': 3,
  '👇': 1,
  '💆': 1,
  '🍴': 3,
  '😧': 0,
  '🇸': 3,
  '😮': 1,
  '▓': 0,
  '🚫': -2,
  '😽': 3,
  '🌈': 3,
  '🙀': 2,
  '⚠': 0,
  '🎮': 2,
  '╯': 0,
  '🍆': 2,
  '🍰': 2,
  '✓': 1,
  '👐': 0,
  '🙇': 1,
  '🍟': 2,
  '🍌': 2,
  '💑': 3,
  '👬': 0,
  '🐣': 2,
  '🎃': 3,
  '▬': 2,
  '😟': 0,
  '🐾': 3,
  '🎓': 3,
  '🏊': 3,
  '🍫': 1,
  '📷': 2,
  '👄': 2,
  '🌼': 4,
  '🚶': -1,
  '🐱': 3,
  '║': 1,
  '🐸': 0,
  '🇺': 3,
  '👿': -3,
  '🚬': 3,
  '✿': 2,
  '📖': 1,
  '🐒': 3,
  '🌍': 3,
  '┊': 5,
  '🐥': 3,
  '🌀': 1,
  '🐼': 1,
  '🎥': 2,
  '💄': 2,
  '💸': 1,
  '⛔': 3,
  '●': 1,
  '🏀': 1,
  '💉': 2,
  '💟': 4,
  '🚗': 1,
  '😯': 1,
  '📝': 1,
  '═': 0,
  '♦': 2,
  '💭': 1
};

module.exports = emojis;
